#
# spec file for package python-vobject
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global modname vobject
Name:           python-vobject
Version:        0.9.6.1
Release:        3.5
Summary:        Python package for parsing and creating iCalendar and vCard files
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://eventable.github.io/%{modname}/
Source:         https://files.pythonhosted.org/packages/source/v/vobject/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module PyICU}
BuildRequires:  %{python_module devel >= 2.7}
BuildRequires:  %{python_module python-dateutil >= 2.4.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.4.0
Requires:       python-six
Requires(post): update-alternatives
Requires(preun):update-alternatives
Recommends:     python-PyICU
Provides:       %{modname} = %{version}
Obsoletes:      %{modname} < 0.9.2
BuildArch:      noarch
%python_subpackages

%description
Parses iCalendar and vCard files into Python data structures,
decoding the relevant encodings. Also serializes vobject data
structures to iCalendar, vCard, or (experimentally) hCalendar
unicode strings.

%prep
%setup -q -n %{modname}-%{version}
# Fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' ACKNOWLEDGEMENTS.txt

%build
%python_build

%install
%python_install
for p in change_tz ics_diff ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec tests.py

%post
%python_install_alternative change_tz
%python_install_alternative ics_diff

%preun
%python_uninstall_alternative change_tz
%python_uninstall_alternative ics_diff

%files %{python_files}
%license LICENSE-2.0.txt
%doc ACKNOWLEDGEMENTS.txt README.md
%python_alternative %{_bindir}/change_tz
%python_alternative %{_bindir}/ics_diff
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}-py*.egg-info

%changelog
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Remove useless service file
- Make the tests unconditional
- Fix the fdupes call
* Tue Nov 20 2018 Hans-Peter Jansen <hpj@urpla.net>
- update to version 0.9.6.1:
  * Revert too-strict serialization of timestamp values
  - broke too many other implementations
- update to version 0.9.6:
  * Correctly order calendar properties before calendar components
    (#98)
  * Correctly serialize timestamp values (i.e. REV) (#99)
  * Pass correct formatting string to logger (#102)
  - thanks @CruzR!
  * RRULE: Fix floating UNTIL with dateutil > 2.6.1 (#115)
  - thanks @Unrud!
  * Encode params if necessary in serialization (#109)
  - thanks @matthias-k!
  * Ignore escaped semi-colons in UNTIL value (#114)
  - thanks @Unrud!
  * RRULE: Fix VTODO without DTSTART (#116)
  - thanks @Unrud!
  * Fixed regexp for VCF Version 2.1 (#121)
  - thanks @farmovit!
  * repr changed for datetime.timedelta in python 3.7 (#122)
  - thanks @sharkcz!
- enable testing
* Thu Aug  3 2017 benoit.monin@gmx.fr
- update to version 0.9.5:
  * Make ics_diff.py work with Python 3
  * Huge changes to text encoding for Python 2/3 compatibility
  * Autogenerate DTSTAMP if not provided
  * Fix getrruleset() for Python 3 and in the case that
    addRDate=True
  * Update vCard property validation to match specifications
  * Handle offset-naive and offset-aware datetimes in recurrence
    rules
  * Improved documentation for multi-value properties
* Mon Jun 19 2017 okurz@suse.com
- Fix source validation
* Tue Jun 13 2017 okurz@suse.com
- Update to 0.9.4.1
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Tue Jul  5 2016 axel.braun@gmx.de
- add obsoletes: vobject to spec file (request from Factory)
* Fri Jun  3 2016 toddrme2178@gmail.com
- Initial version
